from __future__ import division, print_function, absolute_import

import doctest
import glob
import os
import unittest


pdir = os.path.pardir
docs_base = os.path.abspath(os.path.join(os.path.dirname(__file__),
                            pdir, pdir, "doc", "source"))

files = glob.glob(os.path.join(docs_base, "*.rst")) + \
    glob.glob(os.path.join(docs_base, "*", "*.rst"))

suite = doctest.DocFileSuite(*files, module_relative=False, encoding="utf-8")


if __name__ == "__main__":
    unittest.TextTestRunner().run(suite)



#!/usr/bin/env python

"""Helper script for creating image .dat files by numpy.save

Usage:

    python create_dat.py <name of image file> <name of dat file>

Example (to create aero.dat):

    python create_dat.py aero.png aero.dat

Requires Scipy and PIL.
"""

from __future__ import print_function

import sys

import numpy as np


def main():
    from scipy.misc import imread

    if len(sys.argv) != 3:
        print(__doc__)
        exit()

    image_fname = sys.argv[1]
    dat_fname = sys.argv[2]

    data = imread(image_fname)

    np.savez_compressed(dat_fname, data=data)


if __name__ == "__main__":
    main()
